@@ -87,7 +87,7 @@ sub new {
         $self->{myData} = $storage->restore();
 
         if ($self->{myData}{'nextRunDate'}) {
-            $logger->debug (
+            $logger->info (
                 "[".$self->{'path'}."]".
                 " Next server contact planned for ".
                 localtime($self->{'myData'}{'nextRunDate'})
@@ -196,7 +196,7 @@ sub setNextRunDate {
         $time  = time + int rand(($serverdelay?$serverdelay*3600:$config->{delaytime}));
     }
     else{
-        $time = time + ($serverdelay?$serverdelay*3600:$config->{delaytime});
+        $time = time + int rand($serverdelay?$serverdelay*3600:$config->{delaytime});
     }
 
     $self->{'myData'}{'nextRunDate'} = $time;
